===============================
EC2API configuration
===============================

Configuration options
~~~~~~~~~~~~~~~~~~~~~

The following options allow configuration that EC2API supports.


.. include:: ./tables/ec2api-clients.inc
.. include:: ./tables/ec2api-database.inc
.. include:: ./tables/ec2api-service.inc
.. include:: ./tables/ec2api-ec2.inc
.. include:: ./tables/ec2api-s3.inc
.. include:: ./tables/ec2api-common.inc


